@@ -97,7 +97,7 @@ void btn_buttoninfo_add_sheet(ButtonInfo *bti, ButtonSheet *bsh)
 {
 	GList	*iter, *next;
 
-	if(bsh == NULL || bsh == NULL)
+	if(bti == NULL || bsh == NULL)
 		return;
 	for(iter = bti->sheets; iter != NULL; iter = next)
 	{
