@@ -725,13 +725,13 @@ static void init_bdef(MainInfo *min, P_Buttons *page, BDef *def, const gchar *la
 	def->col_bg = od_multibutton_new();
 	od_multibutton_set_text(OD_MULTIBUTTON(def->col_bg), 0, _("Background..."),    NULL, NULL, GUINT_TO_POINTER(face));
 	od_multibutton_set_text(OD_MULTIBUTTON(def->col_bg), 1, _("Reset to Default"), NULL, NULL, GUINT_TO_POINTER(face));
-	g_object_set_data(G_OBJECT(def->col_bg), "face", GINT_TO_POINTER(0));
+	g_object_set_data(G_OBJECT(def->col_bg), "face", GINT_TO_POINTER(face));
 	g_signal_connect(G_OBJECT(def->col_bg), "clicked", G_CALLBACK(evt_col_bg_clicked), page);
 	gtk_box_pack_start(GTK_BOX(hbox), def->col_bg, TRUE, TRUE, 0);
 	def->col_fg = od_multibutton_new();
 	od_multibutton_set_text(OD_MULTIBUTTON(def->col_fg), 0, _("Foreground..."),    NULL, NULL, GUINT_TO_POINTER(face));
 	od_multibutton_set_text(OD_MULTIBUTTON(def->col_fg), 1, _("Reset to Default"), NULL, NULL, GUINT_TO_POINTER(face));
-	g_object_set_data(G_OBJECT(def->col_fg), "face", GINT_TO_POINTER(0));
+	g_object_set_data(G_OBJECT(def->col_fg), "face", GINT_TO_POINTER(face));
 	g_signal_connect(G_OBJECT(def->col_fg), "clicked", G_CALLBACK(evt_col_fg_clicked), page);
 	gtk_box_pack_start(GTK_BOX(hbox), def->col_fg, TRUE, TRUE, 0);
 	gtk_grid_attach(GTK_GRID(grid), hbox, 1, 3, 3, 1);
