@@ -127,11 +127,7 @@ static void copy_and_insert_cmdseq(gpointer key, gpointer data, gpointer user)
 
 		csq_cmdseq_hash(&page->cmdseq, seq);
 
-		gtk_list_store_append(page->store, &titer);
-		gtk_list_store_set(page->store, &titer,
-					CMDSEQ_COLUMN_NAME, seq->name,
-					CMDSEQ_COLUMN_CMDSEQ, seq,
-					-1);
+		gtk_list_store_insert_with_values(page->store, &titer, -1, CMDSEQ_COLUMN_NAME, seq->name, CMDSEQ_COLUMN_CMDSEQ, seq, -1);
 	}
 }
 
@@ -207,8 +203,7 @@ static void populate_dlist(P_CmdSeq *page)
 		for(iter = cs->rows; iter != NULL; iter = g_list_next(iter))
 		{
 			row = iter->data;
-			gtk_list_store_append(page->dstore, &ti);
-			gtk_list_store_set(page->dstore, &ti,
+			gtk_list_store_insert_with_values(page->dstore, &ti, -1,
 						DEF_COLUMN_TYPE, csq_cmdrow_type_to_string(row->type),
 						DEF_COLUMN_DEF,  row->def->str,
 						DEF_COLUMN_ROW,  row,
@@ -470,8 +465,7 @@ static void evt_addrow_clicked(GtkWidget *wid, gpointer user)
 		GtkTreePath	*path;
 
 		csq_cmdseq_row_append(cs, nr);
-		gtk_list_store_append(page->dstore, &iter);
-		gtk_list_store_set(page->dstore, &iter,
+		gtk_list_store_insert_with_values(page->dstore, &iter, -1,
 					DEF_COLUMN_TYPE, csq_cmdrow_type_to_string(nr->type),
 					DEF_COLUMN_DEF,  nr->def->str,
 					DEF_COLUMN_ROW,  nr,
@@ -521,8 +515,7 @@ static void evt_duprow_clicked(GtkWidget *wid, gpointer user)
 	if((nr = csq_cmdrow_copy(row)) != NULL)
 	{
 		csq_cmdseq_row_append(cs, nr);
-		gtk_list_store_append(page->dstore, &riter);
-		gtk_list_store_set(page->dstore, &riter,
+		gtk_list_store_insert_with_values(page->dstore, &riter, -1,
 					DEF_COLUMN_TYPE, csq_cmdrow_type_to_string(nr->type),
 					DEF_COLUMN_DEF,  nr->def->str,
 					DEF_COLUMN_ROW,  nr,
@@ -674,8 +667,7 @@ static void pick_external(P_CmdSeq *page)
 	store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
 	for(i = 0; code[i] != NULL; i+= 2)
 	{
-		gtk_list_store_append(store, &iter);
-		gtk_list_store_set(store, &iter, 0, code[i], 1, code[i + 1], -1);
+		gtk_list_store_insert_with_values(store, &iter, -1, 0, code[i], 1, code[i + 1], -1);
 	}
 	view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), GTK_SELECTION_BROWSE);
@@ -744,8 +736,7 @@ static void evt_add_clicked(GtkWidget *wid, gpointer user)
 	if((ns = csq_cmdseq_new(csq_cmdseq_unique_name(page->cmdseq), 0UL)) == NULL)
 		return;
 	csq_cmdseq_hash(&page->cmdseq, ns);
-	gtk_list_store_append(page->store, &iter);
-	gtk_list_store_set(page->store, &iter,
+	gtk_list_store_insert_with_values(page->store, &iter, -1,
 				CMDSEQ_COLUMN_NAME, ns->name,
 				CMDSEQ_COLUMN_CMDSEQ, ns,
 				-1);
