@@ -3,5 +3,7 @@
 **		command sequence config page.
 */
 
-extern const CfgModule *	ccs_describe(MainInfo *);
-extern GHashTable *		ccs_get_current(void);
+const CfgModule *	ccs_describe(MainInfo *);
+GHashTable *		ccs_get_current(void);
+
+gboolean		ccs_goto_cmdseq(const char *name);
