@@ -132,8 +132,7 @@ static void list_store_append_key(P_Controls *page, const CtrlKey *key, GtkTreeI
 	/* If caller didn't provide an iter to use, use our local. */
 	if(iter == NULL)
 		iter = &myiter;
-	gtk_list_store_append(page->kstore, iter);
-	gtk_list_store_set(page->kstore, iter,
+	gtk_list_store_insert_with_values(page->kstore, iter, -1,
 			KEY_COLUMN_KEYNAME, ctrl_key_get_keyname(key),
 			KEY_COLUMN_CMDSEQ,  ctrl_key_get_cmdseq(key),
 			KEY_COLUMN_KEY,     key,
@@ -159,9 +158,8 @@ static void list_store_append_mouse(P_Controls *page, const CtrlMouse *mouse, Gt
 	/* If caller didn't provide an iter to use, use our local. */
 	if(iter == NULL)
 		iter = &myiter;
-	gtk_list_store_append(page->mstore, iter);
 	btn = ctrl_mouse_get_button(mouse) - 1;
-	gtk_list_store_set(page->mstore, iter,
+	gtk_list_store_insert_with_values(page->mstore, iter, -1,
 			MOUSE_COLUMN_ICON,   page->mpbuf[btn],
 			MOUSE_COLUMN_BUTTON, _(bname[btn]),
 			MOUSE_COLUMN_STATE,  gtk_accelerator_name(0U, ctrl_mouse_get_state(mouse)),
@@ -272,8 +270,7 @@ static gint evt_kadd_clicked(GtkWidget *wid, gpointer user)
 
 	key = ctrl_key_add_unique(page->ctrlinfo);
 	ctrl_key_set_cmdseq(page->ctrlinfo, key, "");
-	gtk_list_store_append(page->kstore, &iter);
-	gtk_list_store_set(page->kstore, &iter,
+	gtk_list_store_insert_with_values(page->kstore, &iter, -1,
 				0, ctrl_key_get_keyname(key),
 				1, ctrl_key_get_cmdseq(key),
 				2, key,
@@ -540,12 +537,10 @@ static void build_mouse_menu(P_Controls *page)
 	** in the model; instead we just use get/set active() on the GtkComboBox.
 	 */
 	mmodel = gtk_list_store_new(2, GDK_TYPE_PIXBUF, G_TYPE_STRING);
-	for(i = 0; i < sizeof gfx / sizeof *gfx; i++)
+	for(i = 0; i < sizeof gfx / sizeof *gfx; ++i)
 	{
 		GtkTreeIter	iter;
-
-		gtk_list_store_append(mmodel, &iter);
-		gtk_list_store_set(mmodel, &iter, 0, page->mpbuf[i], 1, _(label[i]), -1);
+		gtk_list_store_insert_with_values(mmodel, &iter, -1, 0, page->mpbuf[i], 1, _(label[i]), -1);
 	}
 	page->mdcombo = gtk_combo_box_new_with_model(GTK_TREE_MODEL(mmodel));
 	cr = gtk_cell_renderer_pixbuf_new();
