@@ -19,6 +19,9 @@ static gint save(MainInfo *min, FILE *out)
 	xml_put_node_open(out, "Dialogs");
 	switch(min->cfg.dialogs.pos)
 	{
+		case GTK_WIN_POS_NONE:
+			xml_put_text(out, "pos", "none");
+			break;
 		case GTK_WIN_POS_MOUSE:
 			xml_put_text(out, "pos", "mouse");
 			break;
@@ -37,17 +40,18 @@ static void load(MainInfo *min, const XmlNode *node)
 {
 	const gchar	*pos = NULL;
 
+	min->cfg.dialogs.pos = GTK_WIN_POS_NONE;
 	if(xml_get_text(node, "pos", &pos))
 	{
-		if(strcmp(pos, "mouse") == 0)
+		if(strcmp(pos, "none") == 0)
+			min->cfg.dialogs.pos = GTK_WIN_POS_NONE;
+		else if(strcmp(pos, "mouse") == 0)
 			min->cfg.dialogs.pos = GTK_WIN_POS_MOUSE;
 		else if(strcmp(pos, "center") == 0)
 			min->cfg.dialogs.pos = GTK_WIN_POS_CENTER;
 		else
 			fprintf(stderr, "**DIALOGS: Unknown positioning mode \"%s\"\n", pos);
 	}
-	else
-		min->cfg.dialogs.pos = GTK_WIN_POS_MOUSE;
 }
 
 /* ----------------------------------------------------------------------------------------- */
