@@ -165,7 +165,7 @@ static P_DirPane	the_page;	/* There can be only one. */
 static const gchar	*config_name[] = { "DirPaneLeft", "DirPaneRight" },
 			*mode_name[] = { "dirs_first", "dirs_last", "dirs_mixed" },
 			*sbarpos_name[] = { "system", "left", "right" },
-			*pane_orient_name[] = { "horizontal", "vertical", NULL },
+			*pane_orient_name[] = { "horizontal", "vertical" },
 			*pane_splitmode_name[] = { "free", "ratio", "absleft", "absright" };
 
 /* ----------------------------------------------------------------------------------------- */
@@ -183,8 +183,7 @@ static void set_pane_widgets(PDef *def)
 	gtk_list_store_clear(def->sstore);
 	for(i = 0; i < def->edit.num_columns; i++)
 	{
-		gtk_list_store_append(def->sstore, &iter);
-		gtk_list_store_set(def->sstore, &iter,
+		gtk_list_store_insert_with_values(def->sstore, &iter, -1,
 				CONTENT_COLUMN_TITLE, def->edit.format[i].title,
 				CONTENT_COLUMN_DESCRIPTION, dpf_get_content_name(def->edit.format[i].content),
 				CONTENT_COLUMN_CONTENT, def->edit.format[i].content,
@@ -261,8 +260,7 @@ static void evt_aview_row_activated(GtkWidget *wid, GtkTreePath *path, GtkTreeVi
 
 		gtk_tree_model_get(GTK_TREE_MODEL(def->astore), &iter, CONTENT_COLUMN_CONTENT, &content, -1);
 		dpf_set_default_format(&def->edit.format[def->edit.num_columns], (DPContent) content);
-		gtk_list_store_append(def->sstore, &iter);
-		gtk_list_store_set(def->sstore, &iter,
+		gtk_list_store_insert_with_values(def->sstore, &iter, -1,
 				CONTENT_COLUMN_TITLE, def->edit.format[def->edit.num_columns].title,
 				CONTENT_COLUMN_DESCRIPTION, dpf_get_content_name((DPContent) content),
 				CONTENT_COLUMN_CONTENT, content,
@@ -913,13 +911,6 @@ static void evt_flag_rubberbanding_clicked(GtkWidget *wid, gpointer user)
 	def->edit.rubber_banding = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid));
 }
 
-static void evt_flag_rules_clicked(GtkWidget *wid, gpointer user)
-{
-	PDef	*def = user;
-
-	def->edit.rules = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid));
-}
-
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1999-05-15 -	User clicked on one of the "scrollbar position" widgets. Update. */
@@ -980,8 +971,7 @@ static GtkListStore * init_content_list_store(gboolean populate)
 		{
 			if(i == DPC_BLOCKS || i == DPC_BLOCKSIZE)
 				continue;
-			gtk_list_store_append(store, &iter);
-			gtk_list_store_set(store, &iter,
+			gtk_list_store_insert_with_values(store, &iter, -1,
 						CONTENT_COLUMN_TITLE, dpf_get_content_title((DPContent) i),
 						CONTENT_COLUMN_DESCRIPTION, dpf_get_content_name((DPContent) i),
 						CONTENT_COLUMN_CONTENT, i,
@@ -1167,10 +1157,6 @@ static void init_pane_page(P_DirPane *page, guint index, const gchar *other)
 	g_signal_connect(G_OBJECT(def->frband), "clicked", G_CALLBACK(evt_flag_rubberbanding_clicked), def);
 	gtk_grid_attach(GTK_GRID(grid), def->frband, 0, 3, 1, 1);
 
-	def->fruled = gtk_check_button_new_with_label(_("Ruled Rows?"));
-	g_signal_connect(G_OBJECT(def->fruled), "clicked", G_CALLBACK(evt_flag_rules_clicked), def);
-	gtk_grid_attach(GTK_GRID(grid), def->fruled, 1, 2, 1, 1);
-
 	gtk_container_add(GTK_CONTAINER(frame), grid);
 	gtk_box_pack_start(GTK_BOX(hbox), frame, TRUE, TRUE, 0);
 
@@ -1489,7 +1475,6 @@ static void save_pane(FILE *out, DPFormat *fmt, const gchar *node_name)
 	xml_put_boolean(out, "set_font", fmt->set_font);
 	xml_put_text(out, "font_name", fmt->font_name);
 	xml_put_boolean(out, "rubber_banding", fmt->rubber_banding);
-	xml_put_boolean(out, "rules", fmt->rules);
 	xml_put_text(out, "sbar_pos", sbarpos_name[fmt->sbar_pos]);
 	xml_put_node_close(out, node_name);
 }
@@ -1710,8 +1695,6 @@ static void load_pane(const XmlNode *node, DPFormat *fmt)
 			g_snprintf(fmt->font_name, sizeof fmt->font_name, "%s", fontname);
 		if(xml_get_boolean(node, "rubber_banding", &tmp))
 			fmt->rubber_banding = tmp;
-		if(xml_get_boolean(node, "rules", &tmp))
-			fmt->rules = tmp;
 		if(xml_get_text(node, "sbar_pos", &sbarpos))
 		{
 			gboolean	found = FALSE;
@@ -1738,9 +1721,9 @@ static void load_paning(const XmlNode *node, DPPaning *paning)
 	gfloat		tmp;
 
 	if(xml_get_text(node, "orientation", &str))
-		paning->orientation = stu_strcmp_vector(str, pane_orient_name, -1, DPORIENT_HORIZ);
+		paning->orientation = stu_strcmp_vector(str, pane_orient_name, sizeof pane_orient_name / sizeof *pane_orient_name, DPORIENT_HORIZ);
 	if(xml_get_text(node, "mode", &str))
-		paning->mode = stu_strcmp_vector(str, pane_splitmode_name, -1, DPSPLIT_FREE);
+		paning->mode = stu_strcmp_vector(str, pane_splitmode_name, sizeof pane_splitmode_name / sizeof *pane_splitmode_name, DPSPLIT_FREE);
 	if(xml_get_real(node, "value", &tmp))
 		paning->value = tmp;
 }
