@@ -50,10 +50,10 @@ static GtkWidget * cer_init(MainInfo *min, gchar **name)
 	page->min = min;
 	page->modified = FALSE;
 
-	page->vbox = gtk_vbox_new(FALSE, 0);
+	page->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 
 	frame = gtk_frame_new(_("Error and Status Message Display"));
-	vbox = gtk_vbox_new(FALSE, 0);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	page->standard = gtk_radio_button_new_with_label(NULL, _("Status Bar, Above Panes"));
 	g_signal_connect(G_OBJECT(page->standard), "toggled", G_CALLBACK(evt_dialog_toggled), page);
 	gtk_box_pack_start(GTK_BOX(vbox), page->standard, FALSE, FALSE, 0);
