@@ -2,4 +2,4 @@
 ** 2001-08-18 -	Interface for the error reporting config module.
 */
 
-extern CfgPage	* cer_describe(MainInfo *min);
+extern const CfgModule *	cer_describe(MainInfo *min);
