@@ -43,11 +43,11 @@ static GtkWidget * init(MainInfo *min, gchar **name)
 	if(name != NULL)
 		*name = _("Menus");
 
-	page->vbox = gtk_vbox_new(FALSE, 0);
+	page->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	page->min  = min;	
 	page->menu = NULL;
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	for(i = 0; i < sizeof page->mcmd / sizeof page->mcmd[0]; i++)
 	{
 		page->mcmd[i] = gtk_button_new_with_label(_(mlab[i]));
