@@ -149,9 +149,8 @@ static void set_widgets_action(P_Styles *page, Style *stl)
 
 		for(iter = alist; iter != NULL; iter = g_list_next(iter))
 		{
-			gboolean	ovr = stl_style_property_get_override(stl, iter->data);
-			gtk_list_store_append(page->dpaction.store, &titer);
-			gtk_list_store_set(page->dpaction.store, &titer,
+			const gboolean	ovr = stl_style_property_get_override(stl, iter->data);
+			gtk_list_store_insert_with_values(page->dpaction.store, &titer, -1,
 						ACTION_COLUMN_NAME, iter->data,
 						ACTION_COLUMN_CMDSEQ, stl_style_property_get_action(stl, iter->data),
 						ACTION_COLUMN_ACTION, iter->data,
@@ -360,24 +359,13 @@ static void evt_vprop_override_toggled(GtkWidget *wid, gpointer user)
 	{
 		if(strcmp(pname, SPN_ICON_UNSEL) == 0)
 			stl_style_property_set_icon(style, pname, stl_style_property_get_icon(style, pname));
-		else
+		else	/* If not an icon, it's a color. */
 		{
 			const GdkColor	*def;
-			GdkColor	tmp;
 
 			/* FIXME: This assumes only background can be non-overridden in root. */
-			if((def = stl_style_property_get_color(style, pname)) == NULL)
-			{
-				GtkStyleContext	*sctx = gtk_widget_get_style_context(GTK_WIDGET(page->min->gui->pane[0].view));
-				GdkRGBA		bg;
-
-				gtk_style_context_get_background_color(sctx, GTK_STATE_FLAG_NORMAL, &bg);
-				tmp.red   = 65535.0 * bg.red;
-				tmp.green = 65535.0 * bg.green;
-				tmp.blue  = 65535.0 * bg.blue;
-				def = &tmp;
-			}
-			stl_style_property_set_color(style, pname, def);
+			if((def = stl_style_property_get_color(style, pname)) != NULL)
+				stl_style_property_set_color(style, pname, def);
 		}
 	}
 	else
@@ -766,8 +754,7 @@ static void build_pvisual(P_Styles *page)
 	label = gtk_label_new(_("Preview"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	store = gtk_list_store_new(2, GDK_TYPE_PIXBUF, G_TYPE_STRING);
-	gtk_list_store_append(store, &iter);
-	gtk_list_store_set(store, &iter, COLUMN_NAME, _(ptxt), -1);
+	gtk_list_store_insert_with_values(store, &iter, -1, COLUMN_NAME, _(ptxt), -1);
 	pv->preview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	pv->pre_icon_r = gtk_cell_renderer_pixbuf_new();
 	pv->pre_icon = gtk_tree_view_column_new_with_attributes("(title)", pv->pre_icon_r, "pixbuf", COLUMN_ICON, NULL);
