@@ -242,13 +242,12 @@ static void reset_widgets(P_Types *page)
 static void update_list(P_Types *page)
 {
 	const GList	*iter;
-	GtkTreeIter	ti;
 
 	gtk_list_store_clear(page->store);
 	for(iter = page->type; iter != NULL; iter = g_list_next(iter))
 	{
-		gtk_list_store_append(page->store, &ti);
-		gtk_list_store_set(page->store, &ti, COLUMN_NAME, ((FType *) iter->data)->name, COLUMN_TYPE, iter->data, -1);
+		GtkTreeIter	ti;
+		gtk_list_store_insert_with_values(page->store, &ti, -1, COLUMN_NAME, ((FType *) iter->data)->name, COLUMN_TYPE, iter->data, -1);
 	}
 }
 
