@@ -22,7 +22,7 @@ typedef struct {
 	GtkWidget	*vbox;				/* Config page structures always begin like this. */
 	GtkWidget	*content;			/* Content built for us by the window module. */
 	GtkWidget	*border[2];			/* Window border spin buttons. */
-	GtkWidget	*dpos[2];			/* Dialog position mode radio buttons. */
+	GtkWidget	*dpos[3];			/* Dialog position mode radio buttons. */
 
 	MainInfo	*min;
 	gboolean	modified;
@@ -81,7 +81,7 @@ static void evt_dialog_position_toggled(GtkWidget *wid, gpointer user)
 static GtkWidget * cwn_init(MainInfo *min, gchar **name)
 {
 	P_Windows	*page = &the_page;
-	GtkWidget	*hbox, *frame, *table, *vbox;
+	GtkWidget	*hbox, *frame, *grid, *vbox;
 	const gchar	*blab[] = { N_("Horizontal"), N_("Vertical") };
 	const gchar	*dlab[] = { N_("Dialog Windows Positioned by Window Manager"), N_("Dialog Windows Follow Mouse"), N_("Dialog Windows Center On Screen") };
 	GtkWindowPosition	dpos[] = { GTK_WIN_POS_NONE, GTK_WIN_POS_MOUSE, GTK_WIN_POS_CENTER };
@@ -95,28 +95,30 @@ static GtkWidget * cwn_init(MainInfo *min, gchar **name)
 
 	page->edit    = NULL;
 
-	page->vbox    = gtk_vbox_new(FALSE, 0);
+	page->vbox    = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	page->content = NULL;
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	frame = gtk_frame_new(_("Window Borders"));
-	table = gtk_table_new(2, 2, FALSE);
+	grid = gtk_grid_new();
 	for(i= 0; i < sizeof blab / sizeof *blab; i++)
 	{
 		GtkWidget	*label;
 
 		label = gtk_label_new(_(blab[i]));
-		gtk_table_attach(GTK_TABLE(table), label, 0, 1, i, i + 1, 0,0,0,0);
+		gtk_grid_attach(GTK_GRID(grid), label, 0, i, 1, 1);
 		page->border[i] = gtk_spin_button_new_with_range(-32768, 32768, 1);
+		gtk_widget_set_hexpand(page->border[i], TRUE);
+		gtk_widget_set_halign(page->border[i], GTK_ALIGN_FILL);
 		gtk_spin_button_set_digits(GTK_SPIN_BUTTON(page->border[i]), 0);
 		g_signal_connect(G_OBJECT(page->border[i]), "value_changed", G_CALLBACK(evt_border_changed), page);
-		gtk_table_attach(GTK_TABLE(table), page->border[i], 1, 2, i, i + 1, GTK_EXPAND|GTK_FILL,0,0,0);
+		gtk_grid_attach(GTK_GRID(grid), page->border[i], 1, i, 1, 1);
 	}
-	gtk_container_add(GTK_CONTAINER(frame), table);
+	gtk_container_add(GTK_CONTAINER(frame), grid);
 	gtk_box_pack_start(GTK_BOX(hbox), frame, TRUE, TRUE, 0);
 
 	frame = gtk_frame_new(_("Dialog Positioning"));
-	vbox  = gtk_vbox_new(FALSE, 0);
+	vbox  = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	for(i = 0; i < sizeof dlab / sizeof *dlab; i++)
 	{
 		page->dpos[i] = gtk_radio_button_new_with_label(group, _(dlab[i]));
