@@ -55,7 +55,7 @@ static mode_t get_checks(const ChmInfo *chm)
 	{
 		for(j = 0; j < sizeof chm->frame[i].check / sizeof *chm->frame[i].check; j++, k++)
 		{
-			if(GTK_TOGGLE_BUTTON(chm->frame[i].check[j])->active)
+			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(chm->frame[i].check[j])))
 				mode |= mask[k];
 		}
 	}
@@ -202,7 +202,7 @@ static void build_frame(ChmInfo *ci, gint pos, gint type)
 	gint	i;
 
 	fr->frame = gtk_frame_new(_(label[pos]));
-	fr->vbox = gtk_vbox_new(FALSE, 0);
+	fr->vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	for(i = 0; i < 3; i++)
 	{
 		fr->check[i] = gtk_check_button_new_with_label(_(check[type * 3 + i]));
@@ -218,9 +218,9 @@ gint cmd_chmod(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	guint		i;
 	GtkWidget	*hbox, *w;
 
-	ci.vbox  = gtk_vbox_new(FALSE, 5);
+	ci.vbox  = gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
 	ci.label = gtk_label_new(_("Protection Bits"));
-	ci.fbox  = gtk_hbox_new(FALSE, 0);
+	ci.fbox  = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	for(i = 0; i < sizeof ci.frame / sizeof ci.frame[0]; i++)
 	{
 		build_frame(&ci, i, (i == 0) ? 0 : 1);
@@ -229,7 +229,7 @@ gint cmd_chmod(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	gtk_box_pack_start(GTK_BOX(ci.vbox), ci.label, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(ci.vbox), ci.fbox,  TRUE,  TRUE, 0);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	w = gtk_label_new(_("Textual"));
 	gtk_box_pack_start(GTK_BOX(hbox), w, FALSE, FALSE, 0);
 	ci.entry_text = gtk_entry_new();
@@ -247,7 +247,7 @@ gint cmd_chmod(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	gtk_box_pack_end(GTK_BOX(hbox), w, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(ci.vbox), hbox, FALSE, FALSE, 0);
 
-	ci.bbox = gtk_hbox_new(FALSE, 0);
+	ci.bbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	ci.all	  = gtk_button_new_with_label(_("All"));
 	ci.none	  = gtk_button_new_with_label(_("None"));
 	ci.toggle = gtk_button_new_with_label(_("Toggle"));
@@ -262,7 +262,7 @@ gint cmd_chmod(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	gtk_box_pack_start(GTK_BOX(ci.bbox), ci.toggle, TRUE, TRUE, 5);
 	gtk_box_pack_start(GTK_BOX(ci.bbox), ci.revert, TRUE, TRUE, 5);
 	gtk_box_pack_start(GTK_BOX(ci.vbox), ci.bbox, TRUE, TRUE, 0);
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	ci.recurse = gtk_check_button_new_with_label(_("Recurse Directories?"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ci.recurse), ci.last_recurse);
 	gtk_box_pack_start(GTK_BOX(hbox), ci.recurse, TRUE, TRUE, 0);
