@@ -39,7 +39,7 @@ typedef struct {
 typedef struct {
 	GtkWidget	*vbox;
 	GtkWidget	*label;
-	GtkWidget	*rowtable;
+	GtkWidget	*rowgrid;
 	URow		row[2];
 	guint		user, group;			/* The currently selected IDs. */
 	gint		user_index, group_index;	/* Indices to default to. */
@@ -173,29 +173,29 @@ gint cmd_chown(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	UsrCategory	cat[] = { UIC_USER, UIC_GROUP };
 	gchar		*labtext[] = { N_("User"), N_("Group") };
 	gint		i, index;
-	GtkWidget	*algn, *label;
+	GtkWidget	*label;
 	GList		*list, *iter;
 	static ChoInfo	cho;
 
-	cho.vbox  = gtk_vbox_new(FALSE, 0);
+	cho.vbox  = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	cho.label = gtk_label_new("");
 	gtk_box_pack_start(GTK_BOX(cho.vbox), cho.label, FALSE, FALSE, 0);
-	cho.rowtable = gtk_table_new(2, 2, FALSE);
-	gtk_box_pack_start(GTK_BOX(cho.vbox), cho.rowtable, FALSE, FALSE, 5);
+	cho.rowgrid = gtk_grid_new();
 	for(i = 0; i < 2; i++)
 	{
-		algn  = gtk_alignment_new(0.9f, 0.0f, 0.0f, 0.0f);
 		label = gtk_label_new(_(labtext[i]));
-		gtk_container_add(GTK_CONTAINER(algn), label);
-		gtk_table_attach(GTK_TABLE(cho.rowtable), algn, 0, 1, i, i+1,  GTK_FILL,0,0,0);
+		gtk_grid_attach(GTK_GRID(cho.rowgrid), label, 0, i, 1, 1);
 		cho.row[i].combo = gtk_combo_box_text_new_with_entry();
 		list = usr_string_list_create(cat[i], cat[i] == UIC_USER ? geteuid() : getgid(), &index);
 		for(iter = list; iter != NULL; iter = g_list_next(iter))
 			gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(cho.row[i].combo), iter->data);
 		gtk_combo_box_set_active(GTK_COMBO_BOX(cho.row[i].combo), index);
 		usr_string_list_destroy(list);
-		gtk_table_attach_defaults(GTK_TABLE(cho.rowtable), cho.row[i].combo, 1, 2, i, i+1);
+		gtk_widget_set_hexpand(cho.row[i].combo, TRUE);
+		gtk_widget_set_halign(cho.row[i].combo, GTK_ALIGN_FILL);
+		gtk_grid_attach(GTK_GRID(cho.rowgrid), cho.row[i].combo, 1, i, 1, 1);
 	}
+	gtk_box_pack_start(GTK_BOX(cho.vbox), cho.rowgrid, FALSE, FALSE, 5);
 	cho.recurse = gtk_check_button_new_with_label(_("Recurse Directories?"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(cho.recurse), cho.last_recurse);
 	gtk_box_pack_start(GTK_BOX(cho.vbox), cho.recurse, FALSE, FALSE, 0);
