@@ -3,4 +3,4 @@
 **		command.
 */
 
-int	cmd_chown(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca);
+extern gint	cmd_chown(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca);
