@@ -4,3 +4,7 @@
 
 extern gint	cmd_configure(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca);
 extern gint	cmd_configuresave(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca);
+
+extern gboolean cmd_configure_autosave(void);
+
+extern void cfg_configurecmd(MainInfo *min);
