@@ -78,7 +78,13 @@ gint cmd_direnter(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		dir = car_keyword_get_value(ca, "dir", NULL);
 	if(dir != NULL)
 	{
-		if(sscanf(dir, "@history[%u]", &index) == 1)	/* Access history buffer? */
+		if(strcmp(dir, "@cwd") == 0)				/* Actual current directory? */
+		{
+			dir = getcwd(uri, sizeof uri);
+			if(dir == NULL)
+				dir = usr_get_home();
+		}
+		else if(sscanf(dir, "@history[%u]", &index) == 1)	/* Access history buffer? */
 		{
 			dir = dph_dirhistory_get_entry(src->hist, index);
 			if(dir == NULL)
@@ -105,7 +111,6 @@ gint cmd_direnter(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		gtk_widget_queue_resize(GTK_WIDGET(src->view));
 		gui_events_flush();
 		dph_state_restore(src);
-		dp_focus_enter_dir(src);
 		dp_show_stats(src);
 		fam_monitor(src);
 		return 1;
