@@ -39,8 +39,10 @@ static gint file_command(MainInfo *min, DirPane *src, const gchar *action)
 		*/
 		if(g_slist_next(slist) == NULL)
 		{
-			if((cmd = stl_style_property_get_action(DP_SEL_TYPE(slist)->style, action)) != NULL)
+			if((cmd = stl_style_property_get_action(dp_row_get_ftype(dp_get_tree_model(src), slist->data)->style, action)) != NULL)
+			{
 				csq_execute(min, cmd);
+			}
 		}
 		else
 		{
@@ -48,9 +50,7 @@ static gint file_command(MainInfo *min, DirPane *src, const gchar *action)
 
 			for(iter = slist; iter != NULL; iter = g_slist_next(iter))
 			{
-				if(!dp_is_selected(src, DP_SEL_ROW(iter)))
-					break;
-				if((cmd = stl_style_property_get_action(DP_SEL_TYPE(iter)->style, action)) != NULL)
+				if((cmd = stl_style_property_get_action(dp_row_get_ftype(dp_get_tree_model(src), iter->data)->style, action)) != NULL)
 					csq_execute(min, cmd);
 			}
 		}
@@ -64,8 +64,7 @@ static gint file_command(MainInfo *min, DirPane *src, const gchar *action)
 /* 1999-05-20 -	New entrypoint for general file action access. Very cool. */
 gint cmd_fileaction(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
-	const gchar	*action;
+	const gchar	*action = car_keyword_get_value(ca, "action", "Default");
 
-	action = car_keyword_get_value(ca, "action", "Default");
 	return file_command(min, src, action);
 }
