@@ -30,14 +30,15 @@ struct gen_info {
 	DirPane		*src, *dst;
 	GSList		*s_slist;		/* Source pane selection. */
 	const GSList	*s_iter;		/* Source selection iterator. */
-	gchar		old_path[PATH_MAX];
 
 	GenBodyFunc	bf;
 	GenActionFunc	af;
 	GenFreeFunc	ff;
+	GError		*error;			/* For action function to report any error in. */
 	gpointer	user;			/* User's data, passed on in callbacks. */
 	gboolean	open;
 	gboolean	need_update;		/* Set if user's action function has been called. */
+	gboolean	ok;			/* Tracks success/fail of last action. */
 
 	Dialog		*dlg;
 };
@@ -61,19 +62,30 @@ static void end_command(struct gen_info *gen)
 		dlg_dialog_sync_destroy(gen->dlg);
 		gen->dlg  = NULL;
 		gen->open = FALSE;
-		fut_cd(gen->old_path, NULL, 0);
 		if(gen->need_update)
 		{
 			if(gen->flags & CGF_SRC)
-				dp_rescan_post_cmd(gen->src);
+				dp_rescan(gen->src);
 			if(!(gen->flags & CGF_NODST))
-				dp_rescan_post_cmd(gen->dst);
+				dp_rescan(gen->dst);
 			gen->need_update = FALSE;
 		}
-		err_show(gen->min);
 	}
 }
 
+/* 2009-09-19 -	Filter out current row, based on its file type. Returns TRUE if row is to be included. */
+static gboolean type_filter(const struct gen_info *gen)
+{
+	/* We need both target file type and actual non-following type. */
+	const GFileType	tft = dp_row_get_file_type(dp_get_tree_model(gen->src), gen->s_iter->data, TRUE);
+	const GFileType	ft = dp_row_get_file_type(dp_get_tree_model(gen->src), gen->s_iter->data, FALSE);
+	if((gen->flags & CGF_NODIRS) && (tft == G_FILE_TYPE_DIRECTORY))
+		return FALSE;
+	else if((gen->flags & CGF_LINKSONLY) && (ft != G_FILE_TYPE_SYMBOLIC_LINK))
+		return FALSE;
+	return TRUE;
+}
+
 /* 1998-05-29 -	Find the first selected entry, initialize body using it, and return 1.
 **		If no selected entry was found, 0 is returned.
 */
@@ -81,12 +93,11 @@ static gint first_body(struct gen_info *gen)
 {
 	for(gen->s_iter = gen->s_slist; gen->s_iter != NULL; gen->s_iter = g_slist_next(gen->s_iter))
 	{
-		if((gen->flags & CGF_NODIRS) && S_ISDIR(DP_SEL_LSTAT(gen->s_iter).st_mode))
-			continue;
-		if((gen->flags & CGF_LINKSONLY) && !(S_ISLNK(DP_SEL_LSTAT(gen->s_iter).st_mode)))
-			continue;
-		gen->bf(gen->min, gen->src, DP_SEL_ROW(gen->s_iter), gen->user);
-		return 1;
+		if(type_filter(gen))
+		{
+			gen->bf(gen->min, gen->src, gen->s_iter->data, gen, gen->user);
+			return 1;
+		}
 	}
 	return 0;
 }
@@ -99,11 +110,9 @@ static void next_or_end(struct gen_info *gen)
 {
 	for(gen->s_iter = g_slist_next(gen->s_iter); gen->s_iter != NULL; gen->s_iter = g_slist_next(gen->s_iter))
 	{
-		if((gen->flags & CGF_NODIRS) && S_ISDIR(DP_SEL_LSTAT(gen->s_iter).st_mode))
+		if(!type_filter(gen))
 			continue;
-		if((gen->flags & CGF_LINKSONLY) && !(S_ISLNK(DP_SEL_LSTAT(gen->s_iter).st_mode)))
-			continue;
-		gen->bf(gen->min, gen->src, DP_SEL_ROW(gen->s_iter), gen->user);
+		gen->bf(gen->min, gen->src, gen->s_iter->data, gen, gen->user);
 		return;
 	}
 	end_command(gen);
@@ -116,12 +125,10 @@ static void all_then_end(struct gen_info *gen)
 {
 	for(; gen->s_iter != NULL; gen->s_iter = g_slist_next(gen->s_iter))
 	{
-		if((gen->flags & CGF_NODIRS) && S_ISDIR(DP_SEL_LSTAT(gen->s_iter).st_mode))
-			continue;
-		if((gen->flags & CGF_LINKSONLY) && !(S_ISLNK(DP_SEL_LSTAT(gen->s_iter).st_mode)))
+		if(!type_filter(gen))
 			continue;
 		gen->need_update = TRUE;
-		if(!gen->af(gen->min, gen->src, gen->dst, DP_SEL_ROW(gen->s_iter), gen->user))
+		if(!gen->af(gen->min, gen->src, gen->dst, gen->s_iter->data, &gen->error, gen->user))
 			break;
 	}
 	end_command(gen);
@@ -136,15 +143,12 @@ gint cmd_generic(MainInfo *min, const gchar *title, guint32 flags, GenBodyFunc b
 	const gchar		*btn1 = N_("_OK|A_ll|_Skip|_Cancel"),
 				*btn2 = N_("_OK|_Skip|_Cancel"), *btn;
 	static struct gen_info	gen;
-	gboolean		ret = FALSE;
 
 	gen.flags = flags;
 	gen.min	  = min;
 	gen.src	  = min->gui->cur_pane;
 	gen.dst	  = dp_mirror(min, gen.src);
 
-	if(!fut_cd(gen.src->dir.path, gen.old_path, sizeof gen.old_path))
-		return 0;
 	if((gen.s_iter = gen.s_slist = dp_get_selection(gen.src)) == NULL)	/* No selection? */
 		return 0;
 
@@ -153,8 +157,10 @@ gint cmd_generic(MainInfo *min, const gchar *title, guint32 flags, GenBodyFunc b
 	gen.ff = ff;
 
 	gen.open = TRUE;
+	gen.error = NULL;
 	gen.user = user;
 	gen.need_update = FALSE;
+	gen.ok = FALSE;
 
 	btn = _((flags & CGF_NOALL) ? btn2 : btn1);
 	gen.dlg = dlg_dialog_sync_new(*(GtkWidget **) user, title, btn);
@@ -169,15 +175,18 @@ gint cmd_generic(MainInfo *min, const gchar *title, guint32 flags, GenBodyFunc b
 		if(flags & CGF_NOALL)		/* Adjust button IDs if no "All" present. */
 			bid_all = -1, bid_skip--, bid_cancel--;
 
-		ret = TRUE;
-		while(gen.open)
+		gen.ok = TRUE;
+		while(gen.open && gen.ok)
 		{
 			reply = dlg_dialog_sync_wait(gen.dlg);
 			if(reply == bid_ok)
 			{
 				gen.need_update = TRUE;
-				if(!gen.af(gen.min, gen.src, gen.dst, DP_SEL_ROW(gen.s_iter), gen.user))
+				if(!(gen.ok = gen.af(gen.min, gen.src, gen.dst, gen.s_iter->data, &gen.error, gen.user)))
+				{
+					err_set_gerror(min, &gen.error, title, dp_get_file_from_row(gen.src, gen.s_iter->data));
 					end_command(&gen);
+				}
 				else
 					next_or_end(&gen);
 			}
@@ -191,5 +200,14 @@ gint cmd_generic(MainInfo *min, const gchar *title, guint32 flags, GenBodyFunc b
 	}
 	if(gen.dlg != NULL)
 		dlg_dialog_sync_destroy(gen.dlg);
-	return ret;
+
+	return gen.ok;
+}
+
+/* 2010-06-13 -	Track the state of an entry widget, allowing the command to execute only for non-empty strings. */
+void cmd_generic_track_entry(gpointer gen, GtkWidget *entry)
+{
+	struct gen_info *real_gen = gen;
+
+	dlg_dialog_track_entry(real_gen->dlg, entry);
 }
