@@ -230,11 +230,11 @@ gint cmd_join(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 					gchar		bbuf[32];
 
 					sze_put_offset(bbuf, sizeof bbuf, dp_row_get_size(m, iter->data), SZE_BYTES_NO_UNIT, 3, ',');
-					gtk_list_store_append(store, &ti);
-					gtk_list_store_set(store, &ti, 0, dp_row_get_name_display(m, iter->data),
-								       1, bbuf,
-								       2, iter->data,
-								       -1);
+					gtk_list_store_insert_with_values(store, &ti, -1,
+										0, dp_row_get_name_display(m, iter->data),
+										1, bbuf,
+								       		2, iter->data,
+								       		-1);
 					if(first == NULL)
 						first = dp_row_get_name_display(m, iter->data);
 				}
