@@ -2,4 +2,4 @@
 ** 1999-06-12 -	A little header for the menu popup command. Very early code.
 */
 
-int	cmd_menupopup(MainInfo *min, DirPane *src, DirPane *dst, CmdArg *ca);
+extern gint	cmd_menupopup(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca);
