@@ -249,7 +249,7 @@ static gboolean rename_map(RenREInfo *ri, GError **err)
 	const gchar	*fromdef, *todef, *remdef;
 	GSList		*iter;
 	GString		*nn, *nr;
-	gsize		fl, tl, rl, i, nl;
+	gsize		fl, rl, i, nl;
 	gboolean	ok = TRUE;
 
 	if((fromdef = gtk_entry_get_text(GTK_ENTRY(ri->map_from))) == NULL)
@@ -263,7 +263,6 @@ static gboolean rename_map(RenREInfo *ri, GError **err)
 
 	/* Totally important: some lengths are in chars (for iteration), some in bytes for g_utf8_strchr(). */
 	fl = strlen(fromdef);
-	tl = g_utf8_strlen(todef, -1);
 	rl = strlen(remdef);
 
 	ovw_overwrite_begin(ri->min, _("\"%s\" Already Exists - Proceed With Rename?"), 0U);
@@ -400,7 +399,7 @@ static void evt_nbook_switchpage(GtkWidget *wid, gpointer page, gint page_num, g
 
 gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
-	GtkWidget		*label, *table;
+	GtkWidget		*label, *grid;
 	static RenREInfo	ri = { NULL };
 	gboolean		ok = TRUE;
 
@@ -416,47 +415,52 @@ gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		g_signal_connect(G_OBJECT(ri.nbook), "switch-page", G_CALLBACK(evt_nbook_switchpage), &ri);
 
 		/* Build the 'Simple' mode's GUI. */
-		ri.r_vbox = gtk_vbox_new(FALSE, 0);
+		ri.r_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 		label = gtk_label_new(_("Look for substring in all filenames, and replace\nit with another string."));
 		gtk_box_pack_start(GTK_BOX(ri.r_vbox), label, FALSE, FALSE, 0);
-		table = gtk_table_new(2, 2, FALSE);
+		grid = gtk_grid_new();
 		label = gtk_label_new(_("Replace"));
-		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
+		gtk_grid_attach(GTK_GRID(grid), label, 0, 0, 1, 1);
 		ri.r_from = gui_dialog_entry_new();
-		gtk_table_attach(GTK_TABLE(table), ri.r_from, 1, 2, 0, 1, GTK_EXPAND|GTK_FILL,0,0,0);
+		gtk_widget_set_hexpand(ri.r_from, TRUE);
+		gtk_widget_set_halign(ri.r_from, GTK_ALIGN_FILL);
+		gtk_grid_attach(GTK_GRID(grid), ri.r_from, 1, 0, 1, 1);
 		label = gtk_label_new(_("With"));
-		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,  0,0,0,0);
+		gtk_grid_attach(GTK_GRID(grid), label, 0, 1, 1, 1);
 		ri.r_to = gui_dialog_entry_new();
-		gtk_table_attach(GTK_TABLE(table), ri.r_to, 1, 2, 1, 2, GTK_EXPAND|GTK_FILL,0,0,0);
-		gtk_box_pack_start(GTK_BOX(ri.r_vbox), table, FALSE, FALSE, 0);
-		table = gtk_table_new(1, 2, FALSE);
+		gtk_grid_attach(GTK_GRID(grid), ri.r_to, 1, 1, 1, 1);
+		gtk_box_pack_start(GTK_BOX(ri.r_vbox), grid, FALSE, FALSE, 0);
+		grid = gtk_grid_new();
 		ri.r_cnocase = gtk_check_button_new_with_label(_("Ignore Case?"));
-		gtk_table_attach(GTK_TABLE(table), ri.r_cnocase, 0, 1, 0, 1, GTK_EXPAND|GTK_FILL,0,0,0);
+		gtk_widget_set_hexpand(ri.r_cnocase, TRUE);
+		gtk_widget_set_halign(ri.r_cnocase, GTK_ALIGN_FILL);
+		gtk_grid_attach(GTK_GRID(grid), ri.r_cnocase, 0, 0, 1, 1);
 		ri.r_cglobal = gtk_check_button_new_with_label(_("Replace All?"));
-		gtk_table_attach(GTK_TABLE(table), ri.r_cglobal, 1, 2, 0, 1, GTK_EXPAND|GTK_FILL,0,0,0);
-		gtk_box_pack_start(GTK_BOX(ri.r_vbox), table, FALSE, FALSE, 0);
+		gtk_grid_attach(GTK_GRID(grid), ri.r_cglobal, 1, 0, 1, 1);
+		gtk_box_pack_start(GTK_BOX(ri.r_vbox), grid, FALSE, FALSE, 0);
 
 		gtk_notebook_append_page(GTK_NOTEBOOK(ri.nbook), ri.r_vbox, gtk_label_new(_("Simple")));
 
 		/* Build the 'Reg Exp' mode's GUI. */
-		ri.re_vbox = gtk_vbox_new(FALSE, 0);
+		ri.re_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 		label = gtk_label_new(	_("Execute the 'From' RE on each filename, storing\n"
 					"parenthesised subexpression matches. Then replace\n"
 					"any occurance of $n in 'To', where n is the index\n"
 					"(counting from 1) of a subexpression, with the text\n"
 					"that matched, and use the result as a new filename."));
-
 		gtk_box_pack_start(GTK_BOX(ri.re_vbox), label, FALSE, FALSE, 0);
-		table = gtk_table_new(2, 2, FALSE);
+		grid = gtk_grid_new();
 		label = gtk_label_new(_("From"));
-		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
+		gtk_grid_attach(GTK_GRID(grid), label, 0, 0, 1, 1);
 		ri.re_from = gui_dialog_entry_new();
-		gtk_table_attach(GTK_TABLE(table), ri.re_from, 1, 2, 0, 1,  GTK_EXPAND|GTK_FILL,0,0,0);
+		gtk_widget_set_hexpand(ri.re_from, TRUE);
+		gtk_widget_set_halign(ri.re_from, GTK_ALIGN_FILL);
+		gtk_grid_attach(GTK_GRID(grid), ri.re_from, 1, 0, 1, 1);
 		label = gtk_label_new(_("To"));
-		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,  0,0,0,0);
+		gtk_grid_attach(GTK_GRID(grid), label, 0, 1, 1, 1);
 		ri.re_to = gui_dialog_entry_new();
-		gtk_table_attach(GTK_TABLE(table), ri.re_to, 1, 2, 1, 2,  GTK_EXPAND|GTK_FILL,0,0,0);
-		gtk_box_pack_start(GTK_BOX(ri.re_vbox), table, FALSE, FALSE, 0);
+		gtk_grid_attach(GTK_GRID(grid), ri.re_to, 1, 1, 1, 1);
+		gtk_box_pack_start(GTK_BOX(ri.re_vbox), grid, FALSE, FALSE, 0);
 		ri.re_cnocase = gtk_check_button_new_with_label(_("Ignore Case?"));
 		gtk_box_pack_start(GTK_BOX(ri.re_vbox), ri.re_cnocase, FALSE, FALSE, 0);
 
@@ -464,30 +468,32 @@ gint cmd_renamere(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		gtk_widget_show_all(ri.re_vbox);
 
 		/* Build the 'Map' mode's GUI. */
-		ri.map_vbox = gtk_vbox_new(FALSE, 0);
+		ri.map_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 		label = gtk_label_new(_("Look for each character in the 'From' string, and replace\n"
 					"any hits with the corresponding character in the 'To' string.\n"
 					"Then, any characters in the 'Remove' string are removed from\n"
 					"the filename, and the result used as the new name for each file."));
 		gtk_box_pack_start(GTK_BOX(ri.map_vbox), label, FALSE, FALSE, 0);
-		table = gtk_table_new(3, 2, FALSE);
+		grid = gtk_grid_new();
 		label = gtk_label_new(_("From"));
-		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
+		gtk_grid_attach(GTK_GRID(grid), label, 0, 0, 1, 1);
 		ri.map_from = gui_dialog_entry_new();
-		gtk_table_attach(GTK_TABLE(table), ri.map_from, 1, 2, 0, 1,  GTK_EXPAND|GTK_FILL,0,0,0);
+		gtk_widget_set_hexpand(ri.map_from, TRUE);
+		gtk_widget_set_halign(ri.map_from, GTK_ALIGN_FILL);
+		gtk_grid_attach(GTK_GRID(grid), ri.map_from, 1, 0, 1, 1);
 		label = gtk_label_new(_("To"));
-		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,  0,0,0,0);
+		gtk_grid_attach(GTK_GRID(grid), label, 0, 1, 1, 1);
 		ri.map_to = gui_dialog_entry_new();
-		gtk_table_attach(GTK_TABLE(table), ri.map_to, 1, 2, 1, 2,  GTK_EXPAND|GTK_FILL,0,0,0);
+		gtk_grid_attach(GTK_GRID(grid), ri.map_to, 1, 1, 1, 1);
 		label = gtk_label_new(_("Remove"));
-		gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,  0,0,0,0);
+		gtk_grid_attach(GTK_GRID(grid), label, 0, 2, 1, 1);
 		ri.map_remove = gui_dialog_entry_new();
-		gtk_table_attach(GTK_TABLE(table), ri.map_remove, 1, 2, 2, 3,  GTK_EXPAND|GTK_FILL,0,0,0);
-		gtk_box_pack_start(GTK_BOX(ri.map_vbox), table, FALSE, FALSE, 0);
+		gtk_grid_attach(GTK_GRID(grid), ri.map_remove, 1, 2, 1, 1);
+		gtk_box_pack_start(GTK_BOX(ri.map_vbox), grid, FALSE, FALSE, 0);
 		gtk_notebook_append_page(GTK_NOTEBOOK(ri.nbook), ri.map_vbox, gtk_label_new(_("Map")));
 
 		/* Build the 'Case' mode's GUI. */
-		ri.case_vbox = gtk_vbox_new(FALSE, 0);
+		ri.case_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 		label = gtk_label_new(_("Changes the case (upper/lower) of the characters\nin the selected filename(s)."));
 		gtk_box_pack_start(GTK_BOX(ri.case_vbox), label, FALSE, FALSE, 0);
 		ri.case_lower = gtk_radio_button_new_with_label(NULL, _("Lower Case?"));
