@@ -223,24 +223,6 @@ static gboolean filter_type(DirPane *dp, const DirRow2 *row, const SelParam *sp)
 	return (sp->type == SM_TYPE_DIRS) ? dir : !dir;
 }
 
-/* 1999-11-14 -	Compute the column of given pane's CList to query to get the wanted data.
-**		The answer is either a column in the 0..(num_columns-1) range, or -1 for
-**		failure.
-*/
-static guint compute_column(DirPane *dp, DPContent content)
-{
-	MainInfo	*min = dp->main;
-	DPFormat	*dpf = &min->cfg.dp_format[dp->index];
-	guint		i;
-
-	for(i = 0; i < dpf->num_columns; i++)
-	{
-		if(dpf->format[i].content == content)
-			return i;
-	}
-	return 0;
-}
-
 /* 2005-06-04 -	Select action fuction. The <action> should be one of the SM_ACTION_ values. */
 static SelAction select_action_func(gint action)
 {
@@ -366,25 +348,27 @@ static void selparam_init_menus(DirPane *dp, GtkWidget *vbox, GtkWidget *opt_men
 				  N_("All types|Directories only|Non-directories only|"),
 				  N_("Select|Unselect|Toggle|") },
 			*mlabel[] = { N_("Set"), N_("Type"), N_("Action") };
-	GtkWidget	*table, *label;
+	GtkWidget	*grid, *label;
 	guint		i;
 
-	table = gtk_table_new(3, 3, FALSE);
+	grid = gtk_grid_new();
 	for(i = 0; i < sizeof mdef / sizeof mdef[0]; i++)
 	{
 		label = gtk_label_new(_(mlabel[i]));
-		gtk_table_attach(GTK_TABLE(table), label, 0, 1, i, i + 1, 0,0,0,0);
+		gtk_grid_attach(GTK_GRID(grid), label, 0, i, 1, 1);
 		opt_menu[i] = build_mode_combo_box(_(mdef[i]));
 		gtk_combo_box_set_active(GTK_COMBO_BOX(opt_menu[i]), *history[i]);
-		gtk_table_attach(GTK_TABLE(table), opt_menu[i], 1, 2, i, i+1, GTK_EXPAND|GTK_FILL,0,0,0);
+		gtk_widget_set_hexpand(opt_menu[i], TRUE);
+		gtk_widget_set_halign(opt_menu[i], GTK_ALIGN_FILL);
+		gtk_grid_attach(GTK_GRID(grid), opt_menu[i], 1, i, 1, 1);
 	}
 	label = gtk_label_new(_("Content"));
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, i, i + 1, 0,0,0,0);
+	gtk_grid_attach(GTK_GRID(grid), label, 0, i, 1, 1);
 	opt_menu[3] = dpf_get_content_combo_box(NULL, NULL);	/* We read out choice later, no callback needed. */
 	gtk_combo_box_set_active(GTK_COMBO_BOX(opt_menu[3]), content_menu_find(dp, *history[3]));
-	gtk_table_attach(GTK_TABLE(table), opt_menu[3], 1, 2, i, i + 1, GTK_EXPAND|GTK_FILL,0,0,0);
+	gtk_grid_attach(GTK_GRID(grid), opt_menu[3], 1, i, 1, 1);
 
-	gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), grid, FALSE, FALSE, 0);
 }
 
 /* 2005-06-04 -	Parse out basic select parameters from command arguments. */
@@ -462,7 +446,7 @@ gint cmd_selectre(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		mptr[2] = &sp.basic.action;
 		mptr[3] = (guint *) &sp.basic.content;
 
-		vbox = gtk_vbox_new(FALSE, 0);
+		vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 		gtk_container_set_border_width(GTK_CONTAINER(vbox), 2);
 		selparam_init_menus(src, vbox, opt_menu, mptr);
 
@@ -602,7 +586,7 @@ gint cmd_selectsuffix(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *c
 			afunc = (action == 0) ? dp_select : (action == 1) ? dp_unselect : dp_toggle;
 			do
 			{
-				if(stu_has_suffix(dp_row_get_name_display(m, &iter), suff))
+				if(g_str_has_suffix(dp_row_get_name_display(m, &iter), suff))
 					afunc(src, &iter);
 
 			} while(gtk_tree_model_iter_next(m, &iter));
@@ -698,7 +682,6 @@ gint cmd_selectshell(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca
 	SelParamShell	sp;
 	const gchar	*str;
 	GString		*cmd;
-	guint		column;
 	gint		reply = DLG_POSITIVE;
 
 	/* Start from previous set of parameters. */
@@ -719,7 +702,7 @@ gint cmd_selectshell(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca
 		Dialog		*dlg;
 	
 		selparam_get_value_pointers(mptr, &sp.basic);
-		vbox = gtk_vbox_new(FALSE, 0);
+		vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 		selparam_init_menus(src, vbox, opt_menu, mptr);
 		label = gtk_label_new(_("Enter shell command to run. The command\nwill have the selected content appended.\nAction is performed on successful exit."));
 		gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
@@ -753,7 +736,6 @@ gint cmd_selectshell(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca
 
 		if(gtk_tree_model_get_iter_first(m, &iter))
 		{
-			column = compute_column(src, sp.basic.content);
 			cmd = g_string_sized_new(4096);		/* Static for simplicity. */
 			sel_action = select_action_func(sp.basic.action);
 			do
