@@ -203,7 +203,6 @@ static void update_preview_ss(const gchar *format, gboolean zero_fill, gint prec
 {
 	goffset		size = spi->file_size, chunk;
 	guint64		pos = 0, part_index;
-	gchar		part[2 * MAXNAMLEN];
 	GtkTreeIter	iter;
 
 	gtk_list_store_clear(spi->preview_store);
@@ -220,19 +219,16 @@ static void update_preview_ss(const gchar *format, gboolean zero_fill, gint prec
 		dpl = get_preview_display(part_index, spi->namegen->num);
 		if(dpl == DISPLAY_NORMAL)
 		{
-			gtk_list_store_append(spi->preview_store, &iter);
+			gchar	part[2 * MAXNAMLEN], part2[2 * MAXNAMLEN], part3[2 * MAXNAMLEN];
 			sze_put_offset(part, sizeof part, pos, SZE_BYTES_NO_UNIT, 0, ',');
-			gtk_list_store_set(spi->preview_store, &iter, 0, part, -1);
 			namegenerator_update_offset(spi->namegen, pos);
-			namegenerator_generate(spi->namegen, part, sizeof part, format, part_index);
-			gtk_list_store_set(spi->preview_store, &iter, 1, part, -1);
-			sze_put_offset(part, sizeof part, chunk, SZE_BYTES_NO_UNIT, 0, ',');
-			gtk_list_store_set(spi->preview_store, &iter, 2, part, -1);
+			namegenerator_generate(spi->namegen, part2, sizeof part2, format, part_index);
+			sze_put_offset(part3, sizeof part3, chunk, SZE_BYTES_NO_UNIT, 0, ',');
+			gtk_list_store_insert_with_values(spi->preview_store, &iter, -1, 0, part, 1, part2, 2, part3, -1);
 		}
 		else if(dpl == DISPLAY_ELLIPSIS)
 		{
-			gtk_list_store_append(spi->preview_store, &iter);
-			gtk_list_store_set(spi->preview_store, &iter, 1, "...", -1);
+			gtk_list_store_insert_with_values(spi->preview_store, &iter, -1, 1, "...", -1);
 		}
 	}
 }
@@ -525,10 +521,9 @@ static void evt_nformat_details_clicked(GtkWidget *button, gpointer user)
 	gsize			i;
 
 	store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
-	for(i = 0; i < sizeof sym_doc / sizeof *sym_doc; i++)
+	for(i = 0; i < sizeof sym_doc / sizeof *sym_doc; ++i)
 	{
-		gtk_list_store_append(store, &iter);
-		gtk_list_store_set(store, &iter, 0, sym_doc[i].symbol, 1, _(sym_doc[i].desc), -1);
+		gtk_list_store_insert_with_values(store, &iter, -1, 0, sym_doc[i].symbol, 1, _(sym_doc[i].desc), -1);
 	}
 	scwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
