@@ -172,7 +172,7 @@ gint car_keyword_get_enum(const CmdArg *ca, const gchar *keyword, gint default_v
 			va_start(arg, default_value);
 			for(index = 0; (word = va_arg(arg, const gchar *)) != NULL; index++)
 			{
-				if(g_strcasecmp(value, word) == 0)
+				if(strcmp(value, word) == 0)
 				{
 					ret = index;
 					break;
@@ -187,7 +187,7 @@ gint car_keyword_get_enum(const CmdArg *ca, const gchar *keyword, gint default_v
 /* 1999-05-07 -	Check if the value for <keyword> was either true or false. The tokens "", "yes",
 **		"true", "1" and "on" all map to TRUE, any other to FALSE. Note that since the
 **		return type is really guint, it's legal to have a default value outside of {0, 1}.
-**		This is not only cool, its sometimes even useful. Case-insensitive, as usual.
+**		This is not only cool, its sometimes even useful.
 ** 2004-12-26 -	Make sure comparison is always done against English strings, too.
 */
 guint car_keyword_get_boolean(const CmdArg *ca, const gchar *keyword, guint default_value)
@@ -203,9 +203,9 @@ guint car_keyword_get_boolean(const CmdArg *ca, const gchar *keyword, guint defa
 
 			for(i = 0; i < sizeof yes / sizeof yes[0]; i++)
 			{
-				if(g_strcasecmp(value, yes[i]) == 0)
+				if(strcmp(value, yes[i]) == 0)
 					return TRUE;
-				if(g_strcasecmp(value, _(yes[i])) == 0)
+				if(strcmp(value, _(yes[i])) == 0)
 					return TRUE;
 			}
 			return FALSE;
@@ -241,7 +241,7 @@ gboolean car_bareword_present(const CmdArg *ca, const gchar *word)
 
 		for(iter = ca->barewords; iter != NULL; iter = g_list_next(iter))
 		{
-			if(g_strcasecmp(iter->data, word) == 0)
+			if(strcmp(iter->data, word) == 0)
 				return TRUE;
 		}
 	}
@@ -265,7 +265,7 @@ guint car_bareword_get_enum(const CmdArg *ca, guint index, guint default_value,
 			va_start(arg, default_value);
 			for(index = 0; (word = va_arg(arg, const gchar *)) != NULL; index++)
 			{
-				if(g_strcasecmp(bw, word) == 0)
+				if(strcmp(bw, word) == 0)
 				{
 					ret = index;
 					break;
