@@ -121,8 +121,7 @@ static void append_liststore_list(const GList *list, GtkListStore *store)
 	{
 		GtkTreeIter	iter;
 
-		gtk_list_store_append(store, &iter);
-		gtk_list_store_set(store, &iter, 0, list->data, -1);
+		gtk_list_store_insert_with_values(store, &iter, -1, 0, list->data, -1);
 	}
 }
 
