@@ -10,7 +10,7 @@
 #include "color_dialog.h"
 
 typedef struct {
-	GtkWidget	*colsel;		/* The core widget. */
+	GtkWidget	*chooser;		/* The core widget. */
 	ColChangedFunc	func;
 	gpointer	user;
 } ColDlg;
@@ -18,20 +18,15 @@ typedef struct {
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1999-05-02 -	This gets called as the user changes color controls in dialog. Call callback. */
-static void evt_color_changed(GtkWidget *wid, gpointer user)
+static void evt_color_activated(GtkWidget *wid, GdkRGBA *color, gpointer user)
 {
-	ColDlg		*dlg = user;
+	ColDlg	*dlg = user;
 
 	if(dlg->func != NULL)
-	{
-		GdkColor	col;
-
-		gtk_color_selection_get_current_color(GTK_COLOR_SELECTION(dlg->colsel), &col);
-		dlg->func(&col, dlg->user);
-	}
+		dlg->func(color, dlg->user);
 }
 
-gint cdl_dialog_sync_new_wait(const gchar *label, ColChangedFunc func, const GdkColor *initial, gpointer user)
+gint cdl_dialog_sync_new_wait(const gchar *label, ColChangedFunc func, const GdkRGBA *initial, gpointer user)
 {
 	static ColDlg	dlg;
 	Dialog		*d;
@@ -40,12 +35,19 @@ gint cdl_dialog_sync_new_wait(const gchar *label, ColChangedFunc func, const Gdk
 	dlg.func = func;
 	dlg.user = user;
 
-	dlg.colsel = gtk_color_selection_new();
-	g_signal_connect(G_OBJECT(dlg.colsel), "color_changed", G_CALLBACK(evt_color_changed), &dlg);
+	dlg.chooser = gtk_color_chooser_widget_new();
+	g_signal_connect(G_OBJECT(dlg.chooser), "color_activated", G_CALLBACK(evt_color_activated), &dlg);
 	if(initial != NULL)
-		gtk_color_selection_set_current_color(GTK_COLOR_SELECTION(dlg.colsel), initial);
-	d = dlg_dialog_sync_new(dlg.colsel, label ? label : _("Edit Color"), NULL);
+		gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(dlg.chooser), initial);
+	d = dlg_dialog_sync_new(dlg.chooser, label ? label : _("Edit Color"), NULL);
 	ret = dlg_dialog_sync_wait(d);
+	if(ret == DLG_POSITIVE && dlg.func != NULL)
+	{
+		GdkRGBA 	color;
+
+		gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(dlg.chooser), &color);
+		dlg.func(&color, dlg.user);
+	}
 	dlg_dialog_sync_destroy(d);
 
 	return ret;
