@@ -66,6 +66,7 @@ CtrlInfo * ctrl_new(MainInfo *min)
 
 	ctrl = g_malloc(sizeof *ctrl);
 	ctrl->min = min;
+	ctrl->nonumlock = TRUE;
 	ctrl->keys = g_hash_table_new(g_str_hash, g_str_equal);
 	ctrl->keys_inst = NULL;
 
@@ -404,14 +405,14 @@ void ctrl_keys_install(CtrlInfo *ctrl, KbdContext *ctx)
 {
 	if((ctrl != NULL) && (ctx != NULL))
 	{
-		g_hash_table_foreach(ctrl->keys, key_install, ctx);
-		ctrl->keys_inst = g_slist_prepend(ctrl->keys_inst, ctx);
-
 		/* FIXME: This really assumes there is only one attachment. */
 		if(ctrl->nonumlock)
 			kbd_context_mask_set(ctx, GDK_MOD2_MASK);
 		else
-			kbd_context_mask_set(ctx, 0U);
+			kbd_context_mask_set(ctx, 0);
+
+		g_hash_table_foreach(ctrl->keys, key_install, ctx);
+		ctrl->keys_inst = g_slist_prepend(ctrl->keys_inst, ctx);
 	}
 }
 
