@@ -102,7 +102,7 @@ static gboolean evt_sync_key_pressed(GtkWidget *wid, GdkEventKey *evt, gpointer
 {
 	Dialog	*dlg = user;
 
-	if(evt->keyval == GDK_Escape)
+	if(evt->keyval == GDK_KEY_Escape)
 		gtk_dialog_response(GTK_DIALOG(dlg->dlg), dlg->last_button);
 	else
 		return FALSE;
@@ -124,8 +124,8 @@ Dialog * dlg_dialog_sync_new(GtkWidget *body, const gchar *title, const gchar *b
 	dlg = g_malloc(sizeof *dlg);
 	dlg->dlg = win_dialog_open(GTK_WIDGET(the_state.main_window));
 	gtk_window_set_position(GTK_WINDOW(dlg->dlg), the_state.window_pos);
-	g_signal_connect(GTK_OBJECT(dlg->dlg), "key_press_event", G_CALLBACK(evt_sync_key_pressed), dlg);
-	g_signal_connect(GTK_OBJECT(dlg->dlg), "response", G_CALLBACK(evt_sync_response), dlg);
+	g_signal_connect(G_OBJECT(dlg->dlg), "key_press_event", G_CALLBACK(evt_sync_key_pressed), dlg);
+	g_signal_connect(G_OBJECT(dlg->dlg), "response", G_CALLBACK(evt_sync_response), dlg);
 	dlg->stay_open = FALSE;
 	if(title != NULL)
 		win_window_set_title(GTK_WIDGET(dlg->dlg), title);
@@ -134,11 +134,10 @@ Dialog * dlg_dialog_sync_new(GtkWidget *body, const gchar *title, const gchar *b
 	{
 		GtkWidget	*vbox;
 
-		vbox = gtk_vbox_new(FALSE, 0);
+		vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 		gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 		gtk_box_pack_start(GTK_BOX(vbox), body, TRUE, TRUE, 0);
-		gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg->dlg)->vbox), vbox, TRUE, TRUE, 0);
-		gtk_widget_show_all(vbox);
+		gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dlg->dlg))), vbox, TRUE, TRUE, 0);
 	}
 	dlg->last_button = add_buttons(dlg->dlg, buttons);
 	gtk_dialog_set_default_response(GTK_DIALOG(dlg->dlg), 0);
@@ -165,16 +164,6 @@ gint dlg_dialog_sync_new_simple_wait(const gchar *body, const gchar *title, cons
 	return ret;
 }
 
-/* 2009-12-29 -	Adds a widget to the dialog's action area. */
-void dlg_dialog_sync_action_add(Dialog *dlg, GtkWidget *wid)
-{
-	if(dlg != NULL && wid != NULL)
-	{
-		gtk_box_pack_end(GTK_BOX(GTK_DIALOG(dlg->dlg)->action_area), wid, TRUE, TRUE, 0);
-		gtk_widget_show_all(wid);
-	}
-}
-
 /* 2002-08-20 -	Make the dialog stay open until destroyed. Used only by the generic command module,
 **		but on the other hand that module is kind of important.
 */
@@ -191,7 +180,7 @@ gint dlg_dialog_sync_wait(Dialog *dlg)
 {
 	if(dlg != NULL)
 	{
-		gtk_widget_realize(dlg->dlg);
+		gtk_widget_show_all(dlg->dlg);
 		gtk_dialog_run(GTK_DIALOG(dlg->dlg));
 		return dlg->button;
 	}
@@ -230,7 +219,7 @@ static gboolean evt_async_key_pressed(GtkWidget *wid, GdkEventKey *evt, gpointer
 {
 	Dialog	*dlg = user;
 
-	if(evt->keyval == GDK_Escape)
+	if(evt->keyval == GDK_KEY_Escape)
 	{
 		async_close(dlg, dlg->last_button);
 		return TRUE;
@@ -250,7 +239,8 @@ static void evt_async_response(GtkWidget *wid, gint response, gpointer user)
 */
 Dialog * dlg_dialog_async_new(GtkWidget *body, const gchar *title, const gchar *buttons, DlgAsyncFunc func, gpointer user)
 {
-	Dialog		*dlg;
+	Dialog	*dlg;
+	GtkBox	*carea;
 
 	if(buttons == NULL)
 		buttons = _("_OK|_Cancel");
@@ -264,10 +254,10 @@ Dialog * dlg_dialog_async_new(GtkWidget *body, const gchar *title, const gchar *
 	g_signal_connect(G_OBJECT(dlg->dlg), "response", G_CALLBACK(evt_async_response), dlg);
 	if(title != NULL)
 		win_window_set_title(GTK_WIDGET(&GTK_DIALOG(dlg->dlg)->window), title);
-	gtk_container_set_border_width(GTK_CONTAINER(GTK_DIALOG(dlg->dlg)->vbox), 5);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg->dlg)->vbox), body, TRUE, TRUE, 0);
+	carea = GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dlg->dlg)));
+	gtk_container_set_border_width(GTK_CONTAINER(carea), 5);
+	gtk_box_pack_start(carea, body, TRUE, TRUE, 0);
 	dlg->last_button = add_buttons(dlg->dlg, buttons);
-	gtk_widget_realize(dlg->dlg);
 	gtk_widget_show_all(dlg->dlg);
 
 	return dlg;
