@@ -183,10 +183,9 @@ static void completion_update(DirPane *dp, const gchar *prefix)
 			{
 				gchar	buf[4 * PATH_MAX];
 
-				/* Assumes prefix ends with slash. Slighly Unix-centric. */
+				/* Assumes prefix ends with slash. Slightly Unix-centric. */
 				g_snprintf(buf, sizeof buf, "%s%s", prefix, g_file_info_get_name(child));
-				gtk_list_store_append(cm, &iter);
-				gtk_list_store_set(cm, &iter, 0, buf, -1);
+				gtk_list_store_insert_with_values(cm, &iter, -1, 0, buf, -1);
 			}
 			g_object_unref(G_OBJECT(child));
 		}
@@ -985,8 +984,7 @@ static gboolean do_enter_dir(DirPane *dp, const gchar *path, GError **err)
 			else
 				tfi = NULL;
 
-			gtk_list_store_append(dp->dir.store, &iter);
-			gtk_list_store_set(dp->dir.store, &iter,
+			gtk_list_store_insert_with_values(dp->dir.store, &iter, -1,
 					COL_FILE, NULL,
 					COL_INFO, fi,
 					COL_FLAGS, flags,
@@ -1126,9 +1124,8 @@ void dp_history_set(DirPane *dp, const GList *locations)
 
 		if(*name)
 		{
-			gtk_list_store_append(store, &iter);
-			gtk_list_store_set(store, &iter, 0, name, -1);
-			i++;
+			gtk_list_store_insert_with_values(store, &iter, -1, 0, name, -1);
+			++i;
 		}
 	}
 	if(i > 0)
@@ -1915,7 +1912,6 @@ static void dp_build_list(DirPane *dp, const DPFormat *fmt)
 	dp->view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(dp->dir.store));
 	gtk_tree_view_set_search_column(GTK_TREE_VIEW(dp->view), -1);
 	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(dp->view), FALSE);
-	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(dp->view), fmt->rules);
 
 	/* Connect signals. */
 	g_signal_connect(G_OBJECT(dp->view), "button_press_event", G_CALLBACK(evt_dirpane_button_press), dp);
