@@ -151,8 +151,7 @@ static GtkTreeModel * get_content_model(void)
 	{
 		GtkTreeIter	iter;
 
-		gtk_list_store_append(store, &iter);
-		gtk_list_store_set(store, &iter, 0, _(content_info[i].name_full), 1, content_info[i].id, -1);
+		gtk_list_store_insert_with_values(store, &iter,-1, 0, _(content_info[i].name_full), 1, content_info[i].id, -1);
 	}
 	return GTK_TREE_MODEL(store);
 }
@@ -283,7 +282,6 @@ void dpf_init_defaults(CfgInfo *cfg)
 	fmt->huge_parent = FALSE;
 	fmt->set_font = FALSE;
 	fmt->rubber_banding = FALSE;
-	fmt->rules = FALSE;
 	cfg->dp_format[1] = cfg->dp_format[0];	/* Duplicate default formats for second pane. */
 
 	cfg->dp_paning.orientation = DPORIENT_HORIZ;
@@ -450,24 +448,6 @@ static void format_colors_row(GtkTreeModel *model, const DirRow2 *row, GtkCellRe
 	}
 }
 
-/* 2012-05-29 -	Figure out whether the DirPane being formatted using <extra> would like to override the background
-**		color for pane rows, or not. This is Rather Extreme Trickery, you're not expected to consider this
-**		much of a shining beacon when it comes to design. But it is kind of practical, and should be safe
-**		as far as I know.
-*/
-static gboolean get_do_bg(GtkTreeViewColumn *tc, const DpCExtra *extra)
-{
-	/* Rely on the fact that the DpCExtra is embedded in a DpCFmt,
-	** which in turn is part of a DPFormat which has the bit we're after.
-	** If only we knew the column's index ...
-	*/
-	const DpCFmt	*cfmt = (const DpCFmt *) ((const unsigned char *) extra - offsetof(DpCFmt, extra));
-	const gint	index = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(tc), "index"));
-	const DPFormat	*dpf = (const DPFormat *) ((const unsigned char *) cfmt - offsetof(DPFormat, format[index]));
-
-	return !dpf->rules;
-}
-
 static void cdf_name(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
 {
 	const DC_Name	*cfg = user;
@@ -504,7 +484,7 @@ static void cdf_name(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeM
 	else
 		g_object_set(renderer, "text", dname, NULL);
 
-	format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+	format_colors_row(model, iter, renderer, TRUE, TRUE);
 }
 
 static void cdf_size(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -521,7 +501,7 @@ static void cdf_size(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeM
 	size = dp_row_get_size(model, iter);
 	sze_put_offset(buf, sizeof buf, size, cfg->unit, cfg->digits, cfg->ticks ? cfg->tick : '\0');
 	g_object_set(renderer, "text", buf, NULL);
-	format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, (const DpCExtra *) cfg));
+	format_colors_row(model, iter, renderer, TRUE, TRUE);
 }
 
 static void cdf_blocks(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -532,7 +512,7 @@ static void cdf_blocks(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTre
 	blocks = dp_row_get_blocks(model, iter);
 	g_snprintf(buf, sizeof buf, "%" G_GUINT64_FORMAT, blocks);
 	g_object_set(renderer, "text", buf, NULL);
-	format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+	format_colors_row(model, iter, renderer, TRUE, TRUE);
 }
 
 static void cdf_icon(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -579,22 +559,22 @@ static void do_cdf_time(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTr
 
 static void cdf_atime(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
 {
-	do_cdf_time(col, renderer, model, iter, user, dp_row_get_time_accessed(model, iter), get_do_bg(col, user));
+	do_cdf_time(col, renderer, model, iter, user, dp_row_get_time_accessed(model, iter), TRUE);
 }
 
 static void cdf_crtime(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
 {
-	do_cdf_time(col, renderer, model, iter, user, dp_row_get_time_created(model, iter), get_do_bg(col, user));
+	do_cdf_time(col, renderer, model, iter, user, dp_row_get_time_created(model, iter), TRUE);
 }
 
 static void cdf_mtime(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
 {
-	do_cdf_time(col, renderer, model, iter, user, dp_row_get_time_modified(model, iter), get_do_bg(col, user));
+	do_cdf_time(col, renderer, model, iter, user, dp_row_get_time_modified(model, iter), TRUE);
 }
 
 static void cdf_chtime(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
 {
-	do_cdf_time(col, renderer, model, iter, user, dp_row_get_time_changed(model, iter), get_do_bg(col, user));
+	do_cdf_time(col, renderer, model, iter, user, dp_row_get_time_changed(model, iter), TRUE);
 }
 
 static void cdf_devmax(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -603,7 +583,7 @@ static void cdf_devmax(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTre
 
 	g_snprintf(buf, sizeof buf, user, dp_row_get_device(model, iter) >> 8);
 	g_object_set(renderer, "text", buf, NULL);
-	format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+	format_colors_row(model, iter, renderer, TRUE, TRUE);
 }
 
 static void cdf_device(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -612,7 +592,7 @@ static void cdf_device(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTre
 
 	g_snprintf(buf, sizeof buf, user, dp_row_get_device(model, iter));
 	g_object_set(renderer, "text", buf, NULL);
-	format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+	format_colors_row(model, iter, renderer, TRUE, TRUE);
 }
 
 static void cdf_devmin(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -621,7 +601,7 @@ static void cdf_devmin(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTre
 
 	g_snprintf(buf, sizeof buf, user, dp_row_get_device(model, iter) & 255);
 	g_object_set(renderer, "text", buf, NULL);
-	format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+	format_colors_row(model, iter, renderer, TRUE, TRUE);
 }
 
 static void cdf_gidnum(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -630,7 +610,7 @@ static void cdf_gidnum(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTre
 
 	g_snprintf(buf, sizeof buf, user, dp_row_get_gid(model, iter));
 	g_object_set(renderer, "text", buf, NULL);
-	format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+	format_colors_row(model, iter, renderer, TRUE, TRUE);
 }
 
 static void cdf_gidstr(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -648,7 +628,7 @@ static void cdf_gidstr(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTre
 		g_snprintf(buf, sizeof buf, user, gid);
 		g_object_set(renderer, "text", buf, NULL);
 	}
-	format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+	format_colors_row(model, iter, renderer, TRUE, TRUE);
 }
 
 static void cdf_modenum(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -657,7 +637,7 @@ static void cdf_modenum(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTr
 
 	g_snprintf(buf, sizeof buf, user, dp_row_get_mode(model, iter));
 	g_object_set(renderer, "text", buf, NULL);
-	format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+	format_colors_row(model, iter, renderer, TRUE, TRUE);
 }
 
 static void cdf_modestr(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -666,7 +646,7 @@ static void cdf_modestr(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTr
 
 	stu_mode_to_text(buf, sizeof buf, dp_row_get_mode(model, iter));
 	g_object_set(renderer, "text", buf, NULL);
-	format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+	format_colors_row(model, iter, renderer, TRUE, TRUE);
 }
 
 static void cdf_type(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -676,7 +656,7 @@ static void cdf_type(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeM
 	if((ft = dp_row_get_ftype(model, iter)) != NULL)
 	{
 		g_object_set(renderer, "text", ft->name, NULL);
-		format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+		format_colors_row(model, iter, renderer, TRUE, TRUE);
 	}
 }
 
@@ -686,7 +666,7 @@ static void cdf_uidnum(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTre
 
 	g_snprintf(buf, sizeof buf, "%u", dp_row_get_uid(model, iter));
 	g_object_set(renderer, "text", buf, NULL);
-	format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+	format_colors_row(model, iter, renderer, TRUE, TRUE);
 }
 
 static void cdf_uidstr(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -705,7 +685,7 @@ static void cdf_uidstr(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTre
 		g_snprintf(buf, sizeof buf, user, uid);
 		g_object_set(renderer, "text", buf, NULL);
 	}
-	format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+	format_colors_row(model, iter, renderer, TRUE, TRUE);
 }
 
 static void cdf_nlink(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -714,7 +694,7 @@ static void cdf_nlink(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTree
 
 	g_snprintf(buf, sizeof buf, "%u", dp_row_get_nlink(model, iter));
 	g_object_set(renderer, "text", buf, NULL);
-	format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+	format_colors_row(model, iter, renderer, TRUE, TRUE);
 }
 
 static void cdf_uri(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user)
@@ -737,7 +717,7 @@ static void cdf_uri(GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeMo
 		else
 			g_snprintf(buf, sizeof buf, "(failed)");
 		g_object_set(renderer, "text", buf, NULL);
-		format_colors_row(model, iter, renderer, TRUE, get_do_bg(col, user));
+		format_colors_row(model, iter, renderer, TRUE, TRUE);
 	}
 }
 
