@@ -2,4 +2,4 @@
 ** 1998-09-18 -	Header file for the 'file' utility module.
 */
 
-const gchar *	fle_file(MainInfo *min, const gchar *name);
+extern const gchar *	fle_file(MainInfo *min, const gchar *name);
