@@ -37,8 +37,10 @@
 gboolean fut_cd(const gchar *new_dir, gchar *old, gsize old_max)
 {
 	if(old != NULL)
-		getcwd(old, old_max);
-
+	{
+		if(getcwd(old, old_max) == NULL)
+			return FALSE;
+	}
 	return chdir(new_dir) == 0 ? TRUE : FALSE;
 }
 
@@ -300,7 +302,7 @@ gboolean fut_size_gfile(MainInfo *min, const GFile *file, guint64 *bytes, FUCoun
 /* ----------------------------------------------------------------------------------------- */
 
 typedef struct {
-	GStaticMutex	mutex;	/* Lock this before accessing counts. */
+	GMutex		mutex;		/* Lock this before accessing counts. */
 	gboolean	changed;	/* This is set if the data has changed. */
 	FUCount		counts;
 } FUCountSafe;
@@ -329,7 +331,7 @@ static void thread_recurse_directory(GFile *root, SizeGFileInfo *info)
 			const GFileType	type = g_file_info_get_file_type(fin);
 
 			/* Grab the lock, and increase the proper counter based on type. */
-			g_static_mutex_lock(&info->counts.mutex);
+			g_mutex_lock(&info->counts.mutex);
 			info->counts.counts.num_total++;
 			if(type == G_FILE_TYPE_REGULAR)
 			{
@@ -344,7 +346,7 @@ static void thread_recurse_directory(GFile *root, SizeGFileInfo *info)
 				info->counts.counts.num_specials++;
 			info->counts.changed = TRUE;
 			/* All done, release the lock for the rest. */
-			g_static_mutex_unlock(&info->counts.mutex);
+			g_mutex_unlock(&info->counts.mutex);
 
 			/* Wait now, if that was a directory we need to enter it! */
 			if(type == G_FILE_TYPE_DIRECTORY)
@@ -384,10 +386,10 @@ static gboolean cb_size_gfile_timeout(gpointer user)
 		FUCount	local;
 
 		/* Try to quickly create a local copy. */
-		g_static_mutex_lock(&info->counts.mutex);
+		g_mutex_lock(&info->counts.mutex);
 		local = info->counts.counts;
 		info->counts.changed = FALSE;
-		g_static_mutex_unlock(&info->counts.mutex);
+		g_mutex_unlock(&info->counts.mutex);
 
 		/* Then call callback using the local copy, leaving the true data free to
 		 * update by the thread while the GUI-building code in the callback runs.
@@ -407,7 +409,7 @@ gpointer fut_dir_size_gfile_start(GFile *dir, SizeFunc func, gpointer user)
 	info = g_malloc(sizeof *info);
 	info->root = dir;
 	info->cancel = g_cancellable_new();
-	g_static_mutex_init(&info->counts.mutex);
+	g_mutex_init(&info->counts.mutex);
 	info->counts.changed = FALSE;
 	memset(&info->counts.counts, 0, sizeof info->counts.counts);
 	info->depth = 0;
@@ -416,7 +418,7 @@ gpointer fut_dir_size_gfile_start(GFile *dir, SizeFunc func, gpointer user)
 
 	info->timeout = g_timeout_add(350, cb_size_gfile_timeout, info);
 
-	info->thread = g_thread_create(size_gfile_thread_func, info, TRUE, NULL);
+	info->thread = g_thread_new("gentoo:dirsize", size_gfile_thread_func, info);
 
 	return info;
 }
