@@ -2,4 +2,4 @@
 ** 1999-06-19 -	New header for the rewritten hash dialog module. Now synchronous.
 */
 
-const gchar *	hdl_dialog_sync_new_wait(GHashTable *hash, const gchar *title);
+extern const gchar *	hdl_dialog_sync_new_wait(GHashTable *hash, const gchar *title);
