@@ -24,7 +24,7 @@ typedef struct {
 } KEGdkEvent;
 
 typedef struct {
-	GtkObject	*obj;		/* Which object to signal. */
+	GObject		*obj;		/* Which object to signal. */
 	gchar		*signame;	/* Name of signal to emit. */
 	gpointer	user;		/* User data passed along signal emission. */
 } KEObject;
@@ -105,7 +105,7 @@ static KbdEntry * entry_new(const gchar *key, KEType type, va_list args)
 			ent->entry.gdkevent.user  = va_arg(args, gpointer);
 			break;
 		case KET_GTKOBJECT:
-			ent->entry.object.obj	  = va_arg(args, GtkObject *);
+			ent->entry.object.obj	  = va_arg(args, GObject *);
 			ent->entry.object.signame = g_strdup(va_arg(args, gchar *));
 			ent->entry.object.user	  = va_arg(args, gpointer);
 			break;
