@@ -75,11 +75,19 @@ static void od_multibutton_set_page(GtkWidget *widget, guint index)
 		}
 		if(p != NULL)
 		{
+			GtkWidget	*pparent = gtk_widget_get_parent(p);
+
 			if(gtk_widget_get_state_flags(widget) != gtk_widget_get_state_flags(p))
 				gtk_widget_set_state_flags(p, gtk_widget_get_state_flags(widget), TRUE);
 			gtk_widget_show(p);
-			if(gtk_widget_get_parent(p) != NULL)
-				gtk_widget_reparent(p, widget);
+			if(pparent != NULL)
+			{
+				/* Manual reparenting. Semi-legacy code, not sure when this is needed at all. :/ */
+				g_object_ref(p);
+				gtk_container_remove(GTK_CONTAINER(pparent), p);
+				gtk_container_add(GTK_CONTAINER(widget), p);
+				g_object_unref(p);
+			}
 			else
 			{
 				gtk_container_add(GTK_CONTAINER(mb), p);
@@ -417,7 +425,11 @@ void od_multibutton_set_text(ODMultiButton *mb, guint index, const gchar *text,
 		w = gtk_label_new("");
 		od_multibutton_reset_label(mb, index, GTK_LABEL(w), text, bg, fg);
 	}
-	gtk_misc_set_alignment(GTK_MISC(w), 0.5f, 0.5f);
+	if(GTK_IS_LABEL(w))
+	{
+		gtk_label_set_xalign(GTK_LABEL(w), 0.5f);
+		gtk_label_set_yalign(GTK_LABEL(w), 0.5f);
+	}
 	od_multibutton_set_widget(mb, index, w, user);
 }
 
