@@ -75,7 +75,7 @@ OvwRes ovw_overwrite_unary_file(DirPane *dst, const GFile *dst_file)
 	if((fi = g_file_query_info((GFile *) dst_file, "standard::*", 0, NULL, NULL)) != NULL)
 	{
 		gchar		buf[PATH_MAX + 2048], *dn;
-		gint		dlg_res, len;
+		gint		dlg_res;
 
 		if(ovw_info.do_all)			/* Already answered "All"? */
 			res = proceed_file(fi);
@@ -84,7 +84,7 @@ OvwRes ovw_overwrite_unary_file(DirPane *dst, const GFile *dst_file)
 		else
 		{
 			dn = g_file_get_parse_name((GFile *) dst_file);
-			len = g_snprintf(buf, sizeof buf, ovw_info.fmt, dn);
+			g_snprintf(buf, sizeof buf, ovw_info.fmt, dn);
 			g_free(dn);
 			gtk_label_set_text(GTK_LABEL(ovw_info.label), buf);
 
