@@ -9,8 +9,8 @@ typedef struct QueueInfo	QueueInfo;
 
 typedef enum { QEVT_CONTINUE_CMD, QEVT_END_CMD } QEvt;
 
-QueueInfo *	que_initialize(void);
+extern QueueInfo *	que_initialize(void);
 
-void		que_enqueue(MainInfo *min, QEvt evt, ...);
+extern void		que_enqueue(MainInfo *min, QEvt evt, ...);
 
 #endif		/* QUEUE_H */
