@@ -2,4 +2,4 @@
 ** 1999-05-24 -	A rewritten style selection dialog module. Very handy.
 */
 
-Style *	sdl_dialog_sync_new_wait(StyleInfo *si, Style *ignore);
+extern Style *	sdl_dialog_sync_new_wait(StyleInfo *si, Style *ignore);
