@@ -724,11 +724,11 @@ GtkWidget * txv_open(MainInfo *min, const gchar *label)
 	else
 		txi->blabel = gtk_label_new("");
 	gtk_label_set_ellipsize(GTK_LABEL(txi->blabel), PANGO_ELLIPSIZE_MIDDLE);
-	gtk_misc_set_alignment(GTK_MISC(txi->blabel), 0.0f, 0.5f);
+	gtk_label_set_xalign(GTK_LABEL(txi->blabel), 0.f);
 	gtk_box_pack_start(GTK_BOX(txi->bhbox), txi->blabel, TRUE, TRUE, 10);
 
 	txi->bplabel = gtk_label_new("");
-	gtk_misc_set_alignment(GTK_MISC(txi->bplabel), 1.0f, 0.5f);
+	gtk_label_set_xalign(GTK_LABEL(txi->bplabel), 1.0f);
 	gtk_box_pack_start(GTK_BOX(txi->bhbox), txi->bplabel, FALSE, FALSE, 0);
 
 	accel = gtk_accel_group_new();
