@@ -18,7 +18,6 @@
 #include "gentoo.h"
 
 #include <ctype.h>
-#include <locale.h>
 #include <stdio.h>
 #include <stdarg.h>
 #include <stdlib.h>
@@ -103,8 +102,6 @@ static	struct {
 		gchar	equiv;
 	} esc_seq[] = {	{"&lt;", '<'},		{"&gt;", '>'},		{"&amp;", '&'},
 			{"&apos;", '\''},	{"&quot;", '"'},
-			{"&aring;", ''},	{"&auml;", ''},	{"&ouml;", ''},
-			{"&Aring;", ''},	{"&Auml;", ''},	{"&Ouml;", ''},
 		     };
 #define	NUM_ESC_SEQ	(sizeof esc_seq / sizeof esc_seq[0])
 
@@ -172,7 +169,7 @@ void xml_put_node_open(FILE *out, const gchar *node)
 */
 void xml_put_node_close(FILE *out, const gchar *node)
 {
-	if(put_level >= 0)
+	if(put_level > 0)
 	{
 		put_level--;
 		indent(out);
@@ -198,31 +195,14 @@ void xml_put_uinteger(FILE *out, const gchar *name, guint value)
 
 /* 1998-07-27 -	Output a leaf with a real number.
 ** 2002-06-16 -	Significantly more complex, since we need to do this in ASCII. glib 2.0, please.
+** 2014-12-25 -	Somewhat later: now we really can assume glib 2.x. Right now, it's 2.42.1.
 */
 void xml_put_real(FILE *out, const gchar *name, gfloat value)
 {
-	struct lconv	*lconv;
-	gchar		buf[64], *ptr;
-	gssize		dpl;
+	gchar	buf[G_ASCII_DTOSTR_BUF_SIZE + 1];
 
 	indent(out);
-	g_snprintf(buf, sizeof buf, "%f", value);
-	lconv = localeconv();
-	dpl   = strlen(lconv->decimal_point);
-	if(dpl && (ptr = strchr(buf, *lconv->decimal_point)) != NULL)
-	{
-		if(strncmp(ptr, lconv->decimal_point, dpl) == 0)
-		{
-			gssize	tl;
-
-			*ptr++ = '.';
-			tl = strlen(ptr + dpl - 1);
-			memmove(ptr, ptr + dpl - 1, tl);
-			ptr[tl] = '\0';
-		}
-	}
-	else
-		g_warning(_("XML module emitted locale-dependant real number"));
+	g_ascii_dtostr(buf, sizeof buf, value);
 	fprintf(out, "<%s>%s</%s>\n", name, buf, name);
 }
 
